OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Taken",
    "Due yesterday" : "Gisteren vervallen",
    "Due today" : "Vervalt vandaag",
    "Due tomorrow" : "Vervalt morgen",
    "Due on" : "Vervalt op",
    "Started yesterday" : "Begon gisteren",
    "Starts today" : "Begint vandaag",
    "Starts tomorrow" : "Begint morgen",
    "Started on" : "Begint op",
    "Starts on" : "Begint op",
    "[Remind me yesterday at ]HH:mm" : "[Herinner me gisteren om ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Herinner me vendaag op ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Herinnder me morgen om ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Herinner me op ]MMM DD, YYYY,[ om ]HH:mm",
    "Yesterday" : "Gisteren",
    "Today" : "Vandaag",
    "Tomorrow" : "Morgen",
    "in %s" : "in %s",
    "%s ago" : "%s geleden",
    "seconds" : "seconden",
    "a minute" : "een minuut",
    "%d minutes" : "%d minuten",
    "an hour" : "een uur",
    "%d hours" : "%d uur",
    "a day" : "een dag",
    "%d days" : "%d dagen",
    "a month" : "een maand",
    "%d months" : "%d maanden",
    "a year" : "een jaar",
    "%d years" : "%d jaar",
    "week" : "week",
    "weeks" : "weken",
    "day" : "dag",
    "days" : "dagen",
    "hour" : "uur",
    "hours" : "uur",
    "minute" : "minuut",
    "minutes" : "minuten",
    "second" : "tweede",
    "before beginning" : "voor aanvang",
    "after beginning" : "na aanvang",
    "before end" : "voor afsluiting",
    "after end" : "na afsluiting",
    "Comment" : "Reactie",
    "Add a comment" : "Reactie toevoegen",
    "This will delete the Calendar \"%s\" and all of its entries." : "Dit verwijdert Kalender \"%s\" en alle afspraken.",
    "The name \"%s\" is already used." : "De naam \"%s\" is al in gebruik.",
    "An empty name is not allowed." : "Een lege naam is niet toegestaan.",
    "Hidden" : "Verborgen",
    "Visible" : "Zichtbaar",
    "Automatic" : "Automatisch",
    "Sunday" : "zondag",
    "Monday" : "maandag",
    "Tuesday" : "dinsdag",
    "Wednesday" : "woensdag",
    "Thursday" : "donderdag",
    "Friday" : "vrijdag",
    "Saturday" : "zaterdag",
    "Add an important item in \"%s\"..." : "Toevoegen belangrijke taak in \"%s\"...",
    "Add an item due today in \"%s\"..." : "Taak die vandaag vervalt in \"%s\" toevoegen...",
    "Add an item in \"%s\"..." : "Taak in \"%s\" toevoegen...",
    "Add a current item in \"%s\"..." : "Actuele taak aan \"%s\" toevoegen...",
    "Add a subtask to \"%s\"..." : "Subtaak aan \"%s\" toevoegen...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n afgeronde taak","%n afgeronde taken"],
    "Hours" : "Uren",
    "Minutes" : "Minuten",
    "Set due date" : "Vervaldatum instellen",
    "%s %% completed" : "%s %% gereed",
    "priority %s: " : "prioriteit %s: ",
    "high" : "hoog",
    "medium" : "gemiddeld",
    "low" : "laag",
    "no priority assigned" : "geen prioriteit vastgesteld",
    "Remind me" : "Herinner me",
    "at the end" : "op het eind",
    "at the beginning" : "aan het begin",
    "Set start date" : "Begindatum instellen",
    "{calendar} shared by {owner}" : "{calendar} gedeeld door {owner}",
    "Unnamed" : "Onbenoemd",
    "Important" : "Belangrijk",
    "Week" : "Week",
    "All" : "Alle",
    "Current" : "Huidige",
    "Completed" : "Afgerond",
    "Delete" : "Verwijderen",
    "Cancel" : "Annuleren",
    "Edit" : "Bewerk",
    "Link" : "Link",
    "Download" : "Downloaden",
    "Save" : "Opslaan",
    "Add List..." : "Toevoegen lijst...",
    "New List" : "Nieuwe lijst",
    "Settings" : "Instellingen",
    "Start of week" : "Begin van de week",
    "Visibility of Smart Collections" : "Zichtbaarheid van Slimme Verzamelingen",
    "Change sort order" : "Volgorde wijzigen",
    "Default" : "Standaard",
    "Due date" : "Vervaldatum",
    "Start date" : "Startdatum",
    "Priority" : "Prioriteit",
    "Alphabetically" : "Alfabetisch",
    "Manually" : "Handmatig",
    "Load remaining completed tasks." : "Overgebleven afgeronde taken laden.",
    "Task is completed" : "Taak is gereed",
    "All day" : "Hele dag",
    "(New category)" : "(Nieuwe categorie)",
    "Select categories..." : "Kies categorieën...",
    "Loading the task..." : "Laden van de taak...",
    "Task not found!" : "Taak niet gevonden!",
    "add a subtask to" : "voeg een subtaak toe aan",
    "Toggle subtasks" : "Wissel subtaken",
    "Toggle completed subtasks" : "Wissel afgeronde subtaken"
},
"nplurals=2; plural=(n != 1);");
